import request from '@/config/axios'

// 新闻 VO
export interface NewsVO {
  id: number // 主键ID
  newsTitle: string // 新闻标题
  newsDesc: string // 新闻描述
  newsContent: string // 新闻内容
  newsPath: string // 新闻路径
  coverImg: string // 封面图片
  newsTypeId: number // 新闻类型ID
  publishTime: Date // 发布时间
}

// 新闻 API
export const NewsApi = {
  // 查询新闻分页
  getNewsPage: async (params: any) => {
    return await request.get({ url: `/portal/news/page`, params })
  },

  // 查询新闻详情
  getNews: async (id: number) => {
    return await request.get({ url: `/portal/news/get?id=` + id })
  },

  // 新增新闻
  createNews: async (data: NewsVO) => {
    return await request.post({ url: `/portal/news/create`, data })
  },

  // 修改新闻
  updateNews: async (data: NewsVO) => {
    return await request.put({ url: `/portal/news/update`, data })
  },

  // 删除新闻
  deleteNews: async (id: number) => {
    return await request.delete({ url: `/portal/news/delete?id=` + id })
  },

  // 导出新闻 Excel
  exportNews: async (params) => {
    return await request.download({ url: `/portal/news/export-excel`, params })
  }
}